#!/usr/bin/env python3
#
# Convert RDS parameter group intom a TF parameter group.
#
# Usage:
#   aws rds describe-db-parameters --db-parameter-group-name your-parameter-group-name | python3 convert.py
#

import json
import sys

VERSION = '1.1.1'

__version__ = VERSION
__author__ = 'Lev Kokotov <lev.kokotov@instacart.com>'

def main():
    body = json.loads(sys.stdin.read())

    if 'Parameters' not in body:
        print('Input is not valid AWS CLI response JSON object with "Parameters" key required.')
        exit(1)

    parameters = body['Parameters']

    print('resource "aws_db_parameter_group" "parameter_group_name" {')

    for parameter in parameters:
        if not parameter['IsModifiable']:
            continue
        if 'ParameterValue' not in parameter:
            continue
        apply_method = 'immediate' if parameter['ApplyType'] == 'dynamic' else 'pending-reboot'
        print('  parameter {')
        print('    apply_method = "{}"'.format(apply_method))
        print('    name         = "{}"'.format(parameter['ParameterName']))
        print('    value        = "{}" # {}'.format(parameter['ParameterValue'], parameter['Description'].replace('\n', ' ').strip()))
        print('  }')

    print('}')



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

from parametergrouptotf import VERSION

setuptools.setup(
    name='aws-rds-parameter-group-to-tf',
    version=VERSION,
    author='Lev Kokotov',
    author_email='lev.kokotov@instacart.com',
    description='Create a Terraform parameter group from an AWS RDS parameter group.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/levkk/aws-rds-parameter-group-to-tf',
    install_requires=[],
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3',
    entry_points={
        'console_scripts': [
            'parametergrouptotf = parametergrouptotf:main',
        ]
    },
)